![alt text](docs/Logo1.png "PyBioNetFit")

PyBioNetFit (PyBNF) is a general-purpose program for parameterizing biological models specified using the BioNetGen
rule-based modeling language (BNGL) or the Systems Biology Markup Language (SBML). PyBioNetFit offers a suite of
parallelized metaheuristic algorithms (differential evolution, particle swarm optimization, scatter search) for
parameter optimization. In addition to model parameterization, PyBNF supports uncertainty quantification by
bootstrapping or Bayesian approaches, and model checking. PyBNF includes an adaptive Markov chain Monte Carlo (MCMC) sampling algorithm, which supports Bayesian inference. PyBNF includes the Biological Property Specification Language
(BPSL) for defining qualitative data for use in parameterization or checking. It runs on most Linux and macOS
workstations as well on computing clusters.

For documentation, refer to [Documentation_PyBioNetFit.pdf](Documentation_PyBioNetFit.pdf) or the online documentation at <https://pybnf.readthedocs.io/en/latest/>.

PyBioNetFit is released under the BSD-3 license. For more information, refer to the
[LICENSE](LICENSE). LANL code designation: C18062
